@@ -1,5 +1,5 @@
 mdes.bcra4r3 <- function(power=.80, alpha=.05, two.tailed=TRUE,
-                        rho2, rho3, rho4, omega4,
+                        rho2, rho3, rho4, esv4=NULL, omega4=esv4/rho4,
                         p=.50, r21=0, r22=0, r23=0, r2t4=0, g4=0,
                         n, J, K, L){
 
@@ -17,7 +17,7 @@ mdes.bcra4r3 <- function(power=.80, alpha=.05, two.tailed=TRUE,
   mdes.out <- list(fun = "mdes.bcra4r3",
                    parms = list(power=power, alpha=alpha, two.tailed=two.tailed,
                                 rho2=rho2, rho3=rho3, rho4=rho4,
-                                omega4=omega4,
+                                esv4=esv4, omega4=omega4,
                                 p=p, r21=r21, r22=r22, r23=r23, r2t4=r2t4, g4=g4,
                                 n=n, J=J, K=K, L=L),
                    df=df,
@@ -31,7 +31,7 @@ mdes.bcra4r3 <- function(power=.80, alpha=.05, two.tailed=TRUE,
 # mdes.bcra4r3(rho4=.05, rho3=.15, rho2=.15, omega4=.50, n=10, J=4, K=4, L=20)
 
 power.bcra4r3 <- function(es=.25, alpha=.05, two.tailed=TRUE,
-                         rho2, rho3, rho4, omega4,
+                         rho2, rho3, rho4, esv4=NULL, omega4=esv4/rho4,
                          p=.50, r21=0, r22=0, r23=0, r2t4=0, g4=0,
                          n, J, K, L){
 
@@ -49,7 +49,7 @@ power.bcra4r3 <- function(es=.25, alpha=.05, two.tailed=TRUE,
   power.out <-  list(fun = "power.bcra4r3",
                      parms = list(es=es, alpha=alpha, two.tailed=two.tailed,
                                   rho2=rho2, rho3=rho3, rho4=rho4,
-                                  omega4=omega4,
+                                  esv4=esv4, omega4=omega4,
                                   p=p, r21=r21, r22=r22, r23=r23, r2t4=r2t4, g4=g4,
                                   n=n, J=J, K=K, L=L),
                      df=df,
@@ -63,7 +63,7 @@ power.bcra4r3 <- function(es=.25, alpha=.05, two.tailed=TRUE,
 
 mrss.bcra4r3 <- function(es=.25, power=.80, alpha=.05, two.tailed=TRUE,
                          n, J, K, L0=10, tol=.10,
-                         rho2, rho3, rho4, omega4,
+                         rho2, rho3, rho4, esv4=NULL, omega4=esv4/rho4,
                          p=.50, r21=0, r22=0, r23=0, r2t4=0, g4=0){
 
   user.parms <- as.list(match.call())
@@ -91,7 +91,7 @@ mrss.bcra4r3 <- function(es=.25, power=.80, alpha=.05, two.tailed=TRUE,
                     parms = list(es=es, power=power, alpha=alpha, two.tailed=two.tailed,
                                  n=n, J=J, K=K, L0=L0, tol=tol,
                                  rho2=rho2, rho3=rho3, rho4=rho4,
-                                 omega4=omega4,
+                                 esv4=esv4, omega4=omega4,
                                  p=p, r21=r21, r22=r22, r23=r23, r2t4=r2t4, g4=g4),
                     df=df,
                     ncp = M,
